﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Threading;
using System.Runtime.InteropServices;
using System.Diagnostics;

namespace EPT_I2C_Temperature_Sensor
{
    public partial class EPT_I2C_Temperature_Sensor : Form
    {
        public EPT_I2C_Temperature_Sensor()
        {
            InitializeComponent();

        }

        //Object to organize EPT Device 
        Transfer ept_data = new Transfer();
        //Object to keep track of the SRF10 Sensor
        SRF10 srf10 = new SRF10();

        //Index to store device selection
        Int32 device_index;

        // Main object loader
        private void EPT_570_AP_Active_Transfer_Load(object sender, System.EventArgs e)
        {

            // Call the List Devices function
            ListDevices();
        }

        // Main connection function
        private unsafe Int32 ListDevices()
        {
            Int32 result;
            Int32 num_devices;
            Int32 iCurrentIndex;

            // Open the DLL
            result = EPT_AH_Open(null, null, null);
            if (result != 0)
            {
                MessageBox.Show("Could not attach to the ActiveHost library");
                return 0;
            }

            // Query connected devices
            num_devices = EPT_AH_QueryDevices();

            //Prepare the Combo box for population
            iCurrentIndex = cmbDevList.SelectedIndex;
            cmbDevList.Items.Clear();

            // Go through all available devices
            for (device_index = 0; device_index < num_devices; device_index++)
            {
                String str;
                str = Marshal.PtrToStringAnsi((IntPtr)EPT_AH_GetDeviceName(device_index));
                cmbDevList.Items.Add(str);
            }
            return 0;
        }

        // Open the device
        public unsafe Int32 OpenDevice()
        {
            device_index = (int)cmbDevList.SelectedIndex;
            if (EPT_AH_OpenDeviceByIndex(device_index) == 0)
            {
                String message = "Could not open device " + Marshal.PtrToStringAnsi((IntPtr)EPT_AH_GetDeviceName(device_index))
                                                          + ", "
                                                          + Marshal.PtrToStringAnsi((IntPtr)EPT_AH_GetDeviceSerial(device_index));
                MessageBox.Show(message);
                return 0;
            }
            else
            {
                btnSendByte.Enabled = true;
            //    btnBlkCompare16.Enabled = true;
            }

            // Make the opened device the active device
            if (EPT_AH_SelectActiveDeviceByIndex(device_index) == 0)
            {
                String message = "Error selecting device: %s " + Marshal.PtrToStringAnsi((IntPtr)EPT_AH_GetLastError());
                MessageBox.Show(message);
                return 0;
            }

            // Register the read callback function
            RegisterCallBack();
            btnOpenDevice.Enabled = false;
            btnCloseDevice.Enabled = true;
            return 0;
        }

        private void btnOpenDevice_Click(object sender, EventArgs e)
        {
            //Open the Device
            OpenDevice();
        }

        private void btnCloseDevice_Click(object sender, EventArgs e)
        {
            if (EPT_AH_CloseDeviceByIndex(device_index) != 0)
            {
                btnSendByte.Enabled = false;
            }
            btnOpenDevice.Enabled = true;
            btnCloseDevice.Enabled = false;
        }

        private void btnSendByte_Click(object sender, EventArgs e)
        {
            int ibyte, address_to_device;
            ibyte = Convert.ToInt32(tbSendByte.Text);
            address_to_device = 0;
            EPT_AH_SendByte(address_to_device, (char)ibyte);
        }


        private void btnOk_Click(object sender, EventArgs e)
        {
            Application.Exit();
        }


        private void srf10ParseReceive()
        {
            byte[] result = new byte[4];
            string HexChar = "";

            srf10.Register = ept_data.cBlockBuf[0];
            //result = BitConverter.GetBytes(0x07ca);
            //srf10.Payload = BitConverter.GetBytes(trkbrData.Value);
            result = BitConverter.GetBytes(trkbrData.Value);
            srf10.Payload = result[1];
            //srf10.Payload[1] = result[0];
            HexChar = String.Format("{0:x2}", (uint)System.Convert.ToUInt32(trkbrData.Value.ToString()));
            tbRcvBytes.Text = (HexChar);
            switch (srf10.Register)
            {
                case 0x00:
                    if (ept_data.cBlockBuf.Length > 1)
                    {
                        srf10.Command = ept_data.cBlockBuf[1];
                        initiateRanging();
                    }
                    break;
                case 0x01:
                    break;
                case 0x02:
                    EPT_AH_SendByte(0, (char)srf10.Payload);
                    break;
                case 0x03:
                    break;
                default:
                    break;
            }
        }

        private void initiateRanging()
        {
            srf10.RangeTime = 20;
            switch (srf10.Command)
            {
                case 0x50:
                    break;
                default:
                    break;
            }
        }


    }

    public class Transfer
    {
        public int Command;
        public int Address;
        public uint Length;
        public byte Payload;
        public byte[] cBlockBuf;

    }

    public class SRF10
    {
       public int Command;
       public int Address;
       public int Length;
       public int Register;
       public uint RangeTime;
       public byte Payload;
       public byte[] cBlockBuf;

       public SRF10()
       {
           Command = 0;
           Address = 0;
           Length = 0;
           Payload = 0;
           RangeTime = 0;
       }


    }

}
